app

package
v0.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 14, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Overview

Package app provides shared application lifecycle logic and bootstrap helpers.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Lifecycle

func Lifecycle() fx.Option

Lifecycle returns a fx application lifecycle including application start and stop hooks.

Types

type ConsoleApp

type ConsoleApp struct {
	// contains filtered or unexported fields
}

ConsoleApp runs an app to run as CLI using cobra root command inside a started fx application.

func NewConsoleApp

func NewConsoleApp(modules fx.Option, rootCmd *cobra.Command) *ConsoleApp

func (*ConsoleApp) Run

func (c *ConsoleApp) Run(args []string) error

type Info

type Info struct {
	Name        string
	Version     string
	Environment string
	Debug       bool
}

Info identifies the running application.

Jump to